@@ -10,6 +10,7 @@ from pjson.validate_licenses import validate_license_list
 from pjson.validate_direct_addresses import validate_direct_address_list
 from pjson.validate_taxonomies import validate_taxonomy_list
 from pjson.validate_identifiers import validate_identifier_list
+from pjson.validate_other_names import validate_other_name_list
 
 #from validate_basic import validate_basic_dict
 #from validate_addresses import validate_address_list
@@ -17,7 +18,7 @@ from pjson.validate_identifiers import validate_identifier_list
 #from validate_direct_addresses import validate_direct_address_list
 #from validate_taxonomies import validate_taxonomy_list
 #from validate_identifiers import validate_identifier_list
-#from validate_other_names import validate_other_name_list
+
 
 
 def validate_pjson(j):
